Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(138)

Unified Diff: src/a64/constants-a64.h

Issue 138913010: A64: Make the simulator sampling friendly. (Closed) Base URL: https://v8.googlecode.com/svn/branches/experimental/a64
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/a64/instructions-a64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/a64/constants-a64.h
diff --git a/src/a64/constants-a64.h b/src/a64/constants-a64.h
index 625f9872e506ce56fbd7cab8e662385274fef2ba..4f43f13537c9b966177c69d2da7b890db0d7ff1e 100644
--- a/src/a64/constants-a64.h
+++ b/src/a64/constants-a64.h
@@ -707,12 +707,18 @@ enum MemBarrierOp {
ISB = MemBarrierFixed | 0x00000040
};
// Any load or store.
enum LoadStoreAnyOp {
LoadStoreAnyFMask = 0x0a000000,
LoadStoreAnyFixed = 0x08000000
};
+// Any load pair or store pair.
+enum LoadStorePairAnyOp {
+ LoadStorePairAnyFMask = 0x3a000000,
+ LoadStorePairAnyFixed = 0x28000000
+};
+
#define LOAD_STORE_PAIR_OP_LIST(V) \
V(STP, w, 0x00000000), \
V(LDP, w, 0x00400000), \
@@ -707,12 +707,18 @@ enum MemBarrierOp {
ISB = MemBarrierFixed | 0x00000040
};
-// Any load or store.
+// Any load or store (including pair).
enum LoadStoreAnyOp {
LoadStoreAnyFMask = 0x0a000000,
« no previous file with comments | « no previous file | src/a64/instructions-a64.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698